.. pySlope documentation master file

Welcome to pySlope's documentation!
=============================================


``pySlope`` is a 2D slope stability module based on bishops method of slices. This module allows for the following parameters:
   - unlimited horizontal geological units
   - water table
   - uniform loads
   - line loads
   - slope search limits
 
This module can return plots for the critical failure slope or plots for all failure slopes below a certain factor of safety.

The ``pySlope`` `package repository <https://github.com/JesseBonanno/pySlope>`_ can be found on Github.

.. toctree::
   :maxdepth: 2
   :caption: Installation

   installation

.. toctree::
   :maxdepth: 2
   :caption: Examples

   examples

.. toctree::
   :maxdepth: 2
   :caption: User documentation

   docstrings


